from .sprite_ddf_pb2 import *
from .texture_set_ddf_pb2 import *
from .label_ddf_pb2 import *
from .gui_ddf_pb2 import *
from .gamesys_ddf_pb2 import *
from .sound_ddf_pb2 import *
from .mesh_ddf_pb2 import *
from .model_ddf_pb2 import *
from .tile_ddf_pb2 import *
from .buffer_ddf_pb2 import *
from .atlas_ddf_pb2 import *
from .camera_ddf_pb2 import *
from .physics_ddf_pb2 import *
