"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from defoldsdk.ddf import ddf_extensions_pb2 as ddf_dot_ddf__extensions__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17script/ddf_script.proto\x12\x0bdmScriptDDF\x1a\x18ddf/ddf_extensions.proto"6\n\x06LuaRef\x12\x0e\n\x03ref\x18\x01 \x02(\x05:\x010\x12\x1c\n\x11context_table_ref\x18\x02 \x02(\x05:\x010B\'\n\x1acom.dynamo.ddfscript.protoB\tDdfScript')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'script.ddf_script_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'\n\x1acom.dynamo.ddfscript.protoB\tDdfScript'
    _LUAREF._serialized_start = 66
    _LUAREF._serialized_end = 120
